import React from 'react';
import { MuiThemeProvider as ThemeProvider, StylesProvider } from "@material-ui/core/styles";
import { studentTheme } from "./ui/theme";
import { MuiPickersUtilsProvider } from "@material-ui/pickers";
import MomentUtils from "@date-io/moment";
import { BrowserRouter, Switch, Route, Link } from "react-router-dom"

import "moment/locale/pl"
moment.locale("pl")

import '@/styles/overrides.scss'
import '@/styles/header.scss'

import moment, { Moment } from "moment";
import { route, routes } from "@/routing";

class LocalizedMomentUtils extends MomentUtils {
    getDatePickerHeaderText(date: Moment): string {
        return this.format(date, "d MMM yyyy");
    }
}

function App() {
  return (
      <StylesProvider injectFirst>
          <MuiPickersUtilsProvider utils={ LocalizedMomentUtils } libInstance={ moment }>
              <ThemeProvider theme={ studentTheme }>
                  <BrowserRouter>
                      <header className="header">
                          <div id="logo" className="header__logo">
                              <Link to={ route('home') }>
                                  <img src="img/pg-logotyp.svg"/>
                              </Link>
                          </div>
                          <div className="header__nav">
                              <nav className="header__top"></nav>
                              <nav className="header__bottom"></nav>
                          </div>
                      </header>
                      <Switch>{ routes.map(({ name, content, ...route }) => <Route { ...route } key={ name }>{ content() }</Route>) }</Switch>
                  </BrowserRouter>
              </ThemeProvider>
          </MuiPickersUtilsProvider>
      </StylesProvider>
  );
}

export default App;
