import React, { HTMLProps, useEffect } from "react";
import classNames from "classnames"
import { Breadcrumbs, BreadcrumbsProps, Container, Typography } from "@material-ui/core";
import "@/styles/page.scss"

export type PageProps = {
    title?: string;
} & HTMLProps<any>;

export type PageHeaderProps = {
    maxWidth?: "sm" | "md" | "lg" | false
} & HTMLProps<HTMLDivElement>

export const Page = ({ title, children, ...props }: PageProps) => {
    useEffect(() => {
        document.title = title ? title + " | Praktyka Studencka" : "Praktyka Studencka";
    }, [ title ])

    return <main {...props} className={ classNames("page", props.className) }>
        { children }
    </main>
}

Page.Header = ({ children, maxWidth = false, ...props }: PageHeaderProps) =>
    <section {...props} className={classNames("page__header", props.className)}>
        <Container maxWidth={ maxWidth }>
            { children }
        </Container>
    </section>

Page.Title = ({ children }: HTMLProps<any>) => <Typography variant="h2" className="page__title">{ children }</Typography>

Page.Breadcrumbs = ({ children, ...props }: BreadcrumbsProps) => <Breadcrumbs { ...props}>{ children }</Breadcrumbs>
